Skip to contents

Returns the fitted values on the response scale: expected counts for Poisson, probabilities for binomial, or conditional means for normal.

Usage

# S3 method for class 'sir'
fitted(object, ...)

Arguments

object

A fitted sir object from sir.

...

Additional arguments (unused).

Value

An array with the same dimensions as Y (n1 x n2 x T) containing fitted values on the response scale.