cpp_construct_Wbeta_design_dyn.Rd
Builds the design matrix for updating sender effects when influence covariates vary over time (4D W array: m x m x p x T).
cpp_construct_Wbeta_design_dyn(W_field, X, beta)
List of T cubes, each m x m x p (one per time period).
Three-dimensional array (m x m x T) of network states.
Vector (p x 1) of current receiver parameters.
Matrix (m*m*T x p) design matrix for alpha GLM step.