Extract Residuals from a SIR Model
residuals.sir.RdReturns residuals of the specified type. Response residuals are raw (Y - fitted). Pearson residuals are standardized by the variance function. Deviance residuals are signed square roots of the individual deviance contributions and are most useful for diagnostic plots.
Arguments
- object
A fitted
sirobject fromsir.- type
Character string specifying residual type:
"deviance"(default),"pearson", or"response".- ...
Additional arguments (unused).